pub struct BufferSender { /* private fields */ }Expand description
A sender handle to a memory buffer.
Implementations
Sourceimpl BufferSender
impl BufferSender
Sourcepub async fn send(&self, batch: EventBatch) -> Result<(), SendError<EventBatch>>
pub async fn send(&self, batch: EventBatch) -> Result<(), SendError<EventBatch>>
Sends a batch to the buffer.
If the buffer is full and when_full is Block, this will await until space is available,
propagating backpressure upstream.
Sourcepub fn max_capacity(&self) -> usize
pub fn max_capacity(&self) -> usize
Returns the maximum capacity of the buffer.
Sourcepub fn utilization(&self) -> f64
pub fn utilization(&self) -> f64
Returns the utilization of the buffer as a fraction between 0.0 and 1.0.
Sourcepub fn try_send(
&self,
batch: EventBatch,
) -> Result<(), TrySendError<EventBatch>>
pub fn try_send( &self, batch: EventBatch, ) -> Result<(), TrySendError<EventBatch>>
Try to send without blocking. Returns an error if full.